

game of sticks
=============

Game created using python
-------------------------

- How to run

  * Download the game_of_sticks.py file.
      .. code-block:: bash
         
         git clone https://github.com/ganeshhubale/game_of_sticks.git

  * Run using python3(every linux machine is preinstalled with python3)
      .. code-block:: bash

         python3 game_of_sticks.py

- Installation
    .. code-block:: bash

       pip install sticks
